@@ -11,7 +11,7 @@ from abc import abstractmethod
 from pathlib import Path
 from typing import Iterator
 
-from .core import VcsFileSystemIdentifier, VcsProviderFactory
+from .core import VcsFileSystemIdentifier, VcsProvider, VcsProviderFactory
 
 
 class GitCommonVcsProviderFactory(VcsProviderFactory):
@@ -26,7 +26,7 @@ class GitCommonVcsProviderFactory(VcsProviderFactory):
     def _create_provider(self, path: Path) -> VcsProvider:
         raise NotImplementedError()
 
-    @property()
+    @property
     def vcs_fs_root(self) -> Iterator[VcsFileSystemIdentifier]:
         yield self.__git_dir_provider
         yield self.__git_wt_file_provider
